import {AfterViewInit, Component, OnInit, ViewChild} from '@angular/core';
import {AlarmService} from '../alarm.service';
import {pageSize} from '../../app.constants';
import {WarnListComponent} from '../../modal/warn-list/warn-list.component';
import {OverAllService} from '../../overAll/overAll.service';
import {NzMessageService} from 'ng-zorro-antd';
import {DatePipe} from '@angular/common';

@Component({
    selector: 'smart-alarm-list',
    templateUrl: './alarm-list.component.html',
    styles: [`
        .tag-warn {
            padding: 5px;
        }

        .tag-warn span {
            border: 1px solid #ccc;
            margin-right: 10px;
            display: inline-block;
            margin-bottom: 10px;
            padding: 2px 4px;
            border-radius: 4px;
        }

        :host ::ng-deep .tag-warn .ant-tag {
            margin-right: 0px;
        }
    `]
})
export class AlarmListComponent implements OnInit {
    @ViewChild('warnList') warnList: WarnListComponent;
    eventList = [];
    warnCountList = [];
    groupList = [];
    pageNum = 1;
    pageCount = pageSize;
    timeFormat = "yyyy-MM-dd";

    //条件
    timeType = '1';
    obj = {
        priorityName: null,
        groupid: null,
        equipmentType: null,
        startTime: '',
        endTime: '',
        name: ''
    };

    dateBegin = null;
    dateEnd = null;

    constructor(public alarmSer: AlarmService, public overAllSer: OverAllService, public message: NzMessageService,
                public datePipe: DatePipe) {
        this.changeType();
    }

    ngOnInit() {
        this.getType();
        this.getWarnGroup();
        this.searchValue();
    }

    // ngAfterViewInit(){
    //     this.searchValue();
    // }

    //获取分组
    getWarnGroup() {
        this.overAllSer.findGroup().subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.groupList = res.data;
                }
            }
        );
    }

    //获取资源类型
    getType() {
        this.overAllSer.findType().subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.warnCountList = res.data;
                } else {
                    this.message.info(res.errMsg);
                }
            }
        );
    }

    //时间改变
    changeType() {
        const nowDate = new Date().getTime();
        let day1, day2;
        switch (this.timeType) {
            case'1': {
                this.obj.startTime = this.datePipe.transform(nowDate, 'yyyy-MM-dd') + ' 00:00:00';
                this.obj.endTime = this.datePipe.transform(nowDate, 'yyyy-MM-dd') + ' 23:59:59';
                break;
            }
            case'2': {
                day1 = nowDate - 1 * 24 * 60 * 60 * 1000;
                this.obj.startTime = this.datePipe.transform(day1, 'yyyy-MM-dd') + ' 00:00:00';
                this.obj.endTime = this.datePipe.transform(day1, 'yyyy-MM-dd') + ' 23:59:59';
                break;
            }
            case'3': {
                day1 = nowDate - 3 * 24 * 60 * 60 * 1000;
                day2 = nowDate;
                this.obj.startTime = this.datePipe.transform(day1, 'yyyy-MM-dd') + ' 00:00:00';
                this.obj.endTime = this.datePipe.transform(day2, 'yyyy-MM-dd') + ' 23:59:59';
                break;
            }
            case'4': {
                day1 = nowDate - 7 * 24 * 60 * 60 * 1000;
                day2 = nowDate;
                this.obj.startTime = this.datePipe.transform(day1, 'yyyy-MM-dd') + ' 00:00:00';
                this.obj.endTime = this.datePipe.transform(day2, 'yyyy-MM-dd') + ' 23:59:59';
                break;
            }
            case'5': {
                break;
            }
        }
    }

    //查询
    searchValue() {
        if(this.timeType == "5"){
            this.obj.startTime = this.datePipe.transform(this.dateBegin, 'yyyy-MM-dd HH:mm:ss');
            this.obj.endTime = this.datePipe.transform(this.dateEnd, 'yyyy-MM-dd HH:mm:ss');
        }
        this.warnList.getList(this.obj);
    }
}
