import {Component, OnInit, ViewChild, ElementRef, OnDestroy} from '@angular/core';
import {AlarmService} from '../alarm.service';
import {NzMessageService} from 'ng-zorro-antd';
import {SendLogComponent} from '../modal/send-log/send-log.component';
import {color, pageSize} from '../../app.constants';
import {WarnListComponent} from '../../modal/warn-list/warn-list.component';
import {OverAllService} from '../../overAll/overAll.service';

@Component({
    selector: 'smart-now-alarm',
    templateUrl: './now-alarm.component.html',
    styles: [
            `
            .tag-warn{
                padding: 5px;
            }
            .tag-warn span{
                border: 1px solid #ccc;
                margin-right: 10px;
                display: inline-block;
                margin-bottom: 10px;
                padding: 2px 4px;
                border-radius: 4px;
            }
            :host ::ng-deep .tag-warn .ant-tag{
                margin-right: 0px;
            }
            .tag-warn span.select-border{
                border: 1px solid #6097b7;
                border-radius: 5px;
                padding: 2px;
                margin-right: 5px;
            }
        `
    ]
})
export class NowAlarmComponent implements OnInit, OnDestroy {
    @ViewChild('sendLog') sendLog:SendLogComponent;
    @ViewChild('warnList') warnList:WarnListComponent;

    color = color;
    alarmTotal;
    warnCountList = [];
    loading = false;
    pageCount = pageSize;
    pageNum = 1;
    totalNum;
    time_;

    selectHostId;

    constructor(public alarmSer: AlarmService, public message: NzMessageService,
                public overAllSer:OverAllService) {
    }

    ngOnInit() {
        this.search(null);
        this.getType();
        this.time_ = setInterval(()=>{
            this.search(null);
        },2*60*1000);
    }

    ngOnDestroy(){
        clearInterval(this.time_);
    }

    search(hostid){
        this.selectHostId = hostid;
        const obj = {
            isWaring:'yes',
            hostid:hostid,
        };
        this.warnList.getList(obj);
    }

    getType(){
        this.overAllSer.findHostWarningCount().subscribe(
            (res)=>{
                if(res.errCode == 10000){
                    this.warnCountList = res.data;
                }else{
                    this.message.info(res.errMsg);
                }
            }
        )
    }

    change(e){
        this.pageNum = e;
    }

    //打开modal
    showModal(data){
        this.sendLog.showModal(data);
    }

    getTotal(num){
        this.alarmTotal = num;
    }
}
