import {Component, OnInit, Output, ViewChild} from '@angular/core';
import {BusinessComponent} from '../modal/business/business.component';
import { BusinessService } from '../business.service';
import {TreeNodeInterface} from '../../overAll/basic/basic.component';
import {NzMessageService} from 'ng-zorro-antd';
import {color} from '../../app.constants';
import {CommonService} from '../../shared/common/common.service';

@Component({
    selector: 'smart-b-config',
    templateUrl: './b-config.component.html',
    styles: []
})
export class BConfigComponent implements OnInit {
    @ViewChild('smartBusiness') smartBusiness: BusinessComponent;

    sid;  //节点id
    color = color;
    allChecked = false;

    isLoading = false;   //加载中

    constructor(private busineSer:BusinessService,private message:NzMessageService,
                private commonSer:CommonService) {
    }

    dataSet: any[];
    expandDataCache = {};

    collapse(array: TreeNodeInterface[], data: TreeNodeInterface, $event: boolean): void {
        if ($event === false) {
            if (data.children) {
                data.children.forEach(d => {
                    const target = array.find(a => a.serviceid === d.serviceid);
                    target.expand = false;
                    this.collapse(array, target, false);
                });
            } else {
                return;
            }
        }
    }

    convertTreeToList(root: object): TreeNodeInterface[] {
        const stack = [];
        const array = [];
        const hashMap = {};
        stack.push({ ...root, level: 0, expand: true });

        while (stack.length !== 0) {
            const node = stack.pop();
            this.visitNode(node, hashMap, array);
            if (node.children) {
                for (let i = node.children.length - 1; i >= 0; i--) {
                    stack.push({ ...node.children[ i ], level: node.level + 1, expand: false, parent: node });
                }
            }
        }
        return array;
    }

    visitNode(node: TreeNodeInterface, hashMap: object, array: TreeNodeInterface[]): void {
        if (!hashMap[ node.serviceid ]) {
            hashMap[ node.serviceid ] = true;
            array.push(node);
        }
    }

    toTree(index) {
        this.dataSet.forEach((item,i) => {
            this.expandDataCache[item.serviceid] = this.convertTreeToList(item);
        });
    }

    ngOnInit() {
        this.getList();
    }

    //查询业务树
    getList(){
        this.isLoading = true;
        const data = {
            "sid":this.sid,
        };
        this.busineSer.findChild(data).subscribe(
            (res)=>{
                this.isLoading = false;
                if(res.errCode == 10000){
                    this.dataSet = res.data;
                    this.dataSet.forEach((e,index)=>{
                        e.checked = false;
                        e.children = [];
                    });
                    this.toTree(null);
                }else{
                    this.message.error(res.errMsg);
                }
            }
        )
    }

    //获取下级
    getChildren(item){
        this.isLoading = true;
        const data = {
            "sid":item.serviceid,
        };
        this.busineSer.findChild(data).subscribe(
            (res)=>{
                if (res.data) {
                    res.data.forEach(e=>e.children = []);
                    this.dataSet.forEach(e=>{
                        if(e.serviceid == item.serviceid){
                            e.children = res.data;
                        }
                    });
                    this.toTree(item.service);
                } else {
                    this.message.info('该分组下无资源');
                }
                this.isLoading = false;
            }
        )
    }

    //删除单个资源
    showDeleteConfirm(item) {
       this.commonSer.confirmThing("删除","确定删除该服务",()=>{
            const data = {
                serviceids:[]
            };
            data.serviceids.push(item.serviceid);
            this.busineSer.deleteService(data).subscribe(
                (res)=>{
                    if (res.errCode == 10000) {
                        this.message.success('删除成功');
                        this.getList();
                    } else {
                        this.message.error(res.errMsg);
                    }
                }
            )
       })
    }

    //关联网站
    contract(item){

    }

    //告警时间
    getTime(item){
        console.log(item);
        this.busineSer.selectAlarmsClock(item.serviceid).subscribe(
            (res)=>{
                    if(res.errCode == 10000){
                        let info = "告警时间："+res.data.last.time + "<br>" +"上次告警时间："+res.data.now.time;
                        item.info = info;
                        console.log(this.dataSet);
                    }else{
                        this.message.error(res.errMsg);
                    }
            }
        )
    }

    //添加业务
    showAddModal() {
        this.smartBusiness.showModal('添加业务');
    }

    //编辑业务
    showEditModal(item){
        this.smartBusiness.showEditModal("编辑业务",item)
    }

}
