import {Component, EventEmitter, OnInit, Output} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {EmitService} from '../../../shared/event/eventEmitter';
import {OverAllService} from '../../../overAll/overAll.service';
import {NzMessageService} from 'ng-zorro-antd';
import {BusinessService} from '../../business.service';

@Component({
  selector: 'smart-business',
  templateUrl: './business.component.html',
  styles: []
})
export class BusinessComponent implements OnInit {
    @Output() add = new EventEmitter<any>();

    title;
    isVisiable = false;
    isOkLoading = false;
    validateForm: FormGroup;

    checked = false;  //选择SLA
    serviceId;

    groupid;

    constructor(private fb: FormBuilder, private busineSer: BusinessService,
                private message: NzMessageService, private emitService: EmitService) {
    }

    ngOnInit() {
        this.initForm();
    }

    changeModal(){
        if(this.checked){
            this.validateForm.get('showsla').enable();
        }else{
            this.validateForm.get('showsla').disable();
        }

    }

    //初始化
    initForm(){
        this.checked = false;
        this.validateForm = this.fb.group({
            name: ['', [Validators.required]],
            algorithm: [null],
            showsla: ['99.9000'],
            sortorder: ['1',[Validators.maxLength(3)]],
            parentid: ['1'],
        });
        this.validateForm.get('showsla').disable();
    }

    //获取服务列表
    getServiceList(){

    }

    showModal(title): void {
        this.title = title;
        this.isVisiable = true;
    }

    showEditModal(title,item){
        item.algorithm += "";
        item.showsla += "";
        item.sortorder += "";
        this.title = title;
        this.serviceId = item.serviceid;
        this.isVisiable = true;
        this.validateForm.patchValue(item);
    }

    handleOk() {
        for (let i in this.validateForm.controls) {
            this.validateForm.controls[i].markAsDirty();
            this.validateForm.controls[i].updateValueAndValidity();
        }
        if(this.validateForm.invalid){
            return false;
        }
        this.isOkLoading = true;

        if(this.title == '添加业务'){
            this.create();
        }else{
            this.update();
        }
    }

    create() {
        const data = {
            algorithm:Number(this.validateForm.value.algorithm),
            name:this.validateForm.value.name,
            sortorder:Number(this.validateForm.value.sortorder),
            showsla:this.checked?this.validateForm.value.showsla:0,
            parentid:7
        }
        this.busineSer.createService(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.message.info('添加成功');
                    this.isVisiable = false;
                    this.add.emit();
                    this.initForm();
                } else {
                    this.message.error(res.errMsg);
                }
                this.isOkLoading = false;
            }
        );
    }

    update() {
        const data = {
            algorithm:Number(this.validateForm.value.algorithm),
            name:this.validateForm.value.name,
            sortorder:Number(this.validateForm.value.sortorder),
            showsla:this.checked?this.validateForm.value.showsla:0,
            parentid:7,
            serviceid:this.serviceId
        }
        this.busineSer.updateService(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.message.info('修改成功');
                    this.isVisiable = false;
                    this.add.emit();
                    this.initForm();
                } else {
                    this.message.info(res.errMsg);
                }
                this.isOkLoading = false;
            }
        );
    }

    handleCancel(): void {
        this.isVisiable = false;
        this.initForm();
    }

}
